==> htkc_utils-1.0.1.tar.gz: example/example_app.dart <==
import 'package:flutter/material.dart';
import 'package:htkc_utils/htkc_alert_dialog.dart';
import 'package:htkc_utils/htkc_app_bar.dart';
import 'package:htkc_utils/htkc_utils.dart';

void main() async {
    runApp(const HTKCExample());
}

class HTKCExample extends StatefulWidget {
  const HTKCExample({Key? key}) : super(key: key);

  @override
  State<HTKCExample> createState() => _HTKCExampleState();
}

class _HTKCExampleState extends State<HTKCExample> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: HCustomAppBar(
        title: 'HTKC Example',
        bgColor: Colors.white,
        action: true,
        actionTitle: '+ New',
        isDialog: true,
        actionWidget: const CustomAlertDialog(child: Center(child: Text('Action Widget Clicked'))),
       child: Card(
         clipBehavior: Clip.antiAlias,
         child: Wrap(
           direction: Axis.horizontal,
           spacing: 8.0, // gap between adjacent chips
           runSpacing: 4.0, // gap between lines
           children: <Widget>[
             Chip(
               avatar: CircleAvatar(
                   backgroundColor: Colors.blue.shade900, child: Text('AH')),
               label: Text('Hamilton'),
             ),
             Chip(
               avatar: CircleAvatar(
                   backgroundColor: Colors.blue.shade900, child: Text('ML')),
               label: Text('Lafayette'),
             ),
             Chip(
               avatar: CircleAvatar(
                   backgroundColor: Colors.blue.shade900, child: Text('HM')),
               label: Text('Mulligan'),
             ),
             Chip(
               avatar: CircleAvatar(
                   backgroundColor: Colors.blue.shade900, child: Text('JL')),
               label: Text('Laurens'),
             ),
           ],
         ),
       ),
    ));
  }
}

==> htkc_utils-1.0.3.tar.gz: example/example_app.dart <==
import 'package:flutter/material.dart';
import 'package:htkc_utils/htkc_alert_dialog.dart';
import 'package:htkc_utils/htkc_app_bar.dart';
import 'package:htkc_utils/htkc_utils.dart';

void main() async {
    runApp(const HTKCExample());
}

class HTKCExample extends StatefulWidget {
  const HTKCExample({Key? key}) : super(key: key);

  @override
  State<HTKCExample> createState() => _HTKCExampleState();
}

class _HTKCExampleState extends State<HTKCExample> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: HCustomAppBar(
        title: 'HTKC Example',
        bgColor: Colors.white,
        action: true,
        actionTitle: '+ New',
        isDialog: true,
        actionWidget: const HCustomAlertDialog(child: Center(child: Text('Action Widget Clicked'))),
       child: Card(
         clipBehavior: Clip.antiAlias,
         child: Wrap(
           direction: Axis.horizontal,
           spacing: 8.0, // gap between adjacent chips
           runSpacing: 4.0, // gap between lines
           children: <Widget>[
             Chip(
               avatar: CircleAvatar(
                   backgroundColor: Colors.blue.shade900, child: Text('AH')),
               label: Text('Hamilton'),
             ),
             Chip(
               avatar: CircleAvatar(
                   backgroundColor: Colors.blue.shade900, child: Text('ML')),
               label: Text('Lafayette'),
             ),
             Chip(
               avatar: CircleAvatar(
                   backgroundColor: Colors.blue.shade900, child: Text('HM')),
               label: Text('Mulligan'),
             ),
             Chip(
               avatar: CircleAvatar(
                   backgroundColor: Colors.blue.shade900, child: Text('JL')),
               label: Text('Laurens'),
             ),
           ],
         ),
       ),
    ));
  }
}
